@@ -1,3 +1,4 @@
+import janus
 import tarantool
 
 from async_task_processor.primitives.base_task import BaseTask
@@ -27,7 +28,9 @@ class TarantoolTask(BaseTask):
         self.queue_name = tube.name
         self.connection = connection
         self._tube = tube
+        self._main_tnt = janus.Queue(loop=loop)
         super().__init__(loop, type(self).__name__, foo, args, bind, timeout, max_retries, retry_countdown, name)
+        self.loop.create_task(self._main_tnt_listener())
 
     def set_tube(self, task):
         """
@@ -41,8 +44,26 @@ class TarantoolTask(BaseTask):
     def reset(self):
         self._task, self.data = None, None
 
-    def __call__(self, *args, **kwargs):
-        """Sync tarantool command execute. You may use self(<tarantool_command>) in task function
+    async def _main_tnt_listener(self):
+        while True:
+            func_name, args, timeout = await self._main_tnt.async_q.get()
+            await self.connection.call(func_name, args, timeout=timeout)
+            self._main_tnt.async_q.task_done()
+
+    def __call__(self, func_name, args, timeout=-1):
+        """Async tarantool command execute. You may use self(<tarantool_command>) in task function.
+        Use this method if you want to redeclare ack method for example or bury, release task manually.
+
+        :type func_name: str
+        :type args: list
+        :type timeout: int
+        :return:
+        """
+        self._main_tnt.sync_q.put((func_name, args, timeout))
+        self._main_tnt.sync_q.join()
+
+    def tnt_sync_call(self, *args, **kwargs):
+        """Sync tarantool command execute. You may use self.tnt_sync_call(<tarantool_command>) in task function
 
         :param args:
         :param kwargs:
