@@ -2,7 +2,7 @@ import asyncio
 import sys
 import traceback
 
-from async_task_processor.exceptions import RetryException, MaxRetriesExceedException
+from async_task_processor.exceptions import RetryException
 from async_task_processor.processors.simple_processor import SimpleProcessor
 
 
@@ -32,9 +32,6 @@ class PeriodicProcessor(SimpleProcessor):
                 await asyncio.sleep(task.retry_countdown)
                 task.app.logger.warning(exc)
                 continue
-            except MaxRetriesExceedException as exc:
-                task.app.logger.error(exc)
-                break
             except Exception:
                 task.remove()
                 task.app.logger.error(
