@@ -7,7 +7,7 @@ import asynctnt_queue
 from asynctnt.exceptions import TarantoolNotConnectedError
 from tarantool import NetworkError
 
-from async_task_processor.exceptions import RetryException, MaxRetriesExceedException
+from async_task_processor.exceptions import RetryException
 from async_task_processor.primitives import TarantoolTask
 from async_task_processor.processors.base_processor import BaseProcessor
 
@@ -70,10 +70,9 @@ class TarantoolProcessor(BaseProcessor):
         """
         task_workers = [
             TarantoolTask(loop=self._loop, connection=self._connection, tube=self._queue.tube(queue), foo=foo,
-                          args=args,
-                          bind=bind, timeout=timeout, max_retries=max_retries, retry_countdown=retry_countdown,
-                          conn_max_retries=self._conn_max_retries, conn_retry_countdown=self._conn_retry_countdown,
-                          name=name)
+                          args=args, bind=bind, timeout=timeout, max_retries=max_retries,
+                          retry_countdown=retry_countdown, conn_max_retries=self._conn_max_retries,
+                          conn_retry_countdown=self._conn_retry_countdown, name=name)
             for _ in range(max_workers)]
         super().add_task(task_workers=task_workers)
 
@@ -116,9 +115,6 @@ class TarantoolProcessor(BaseProcessor):
                     await asyncio.sleep(task.retry_countdown)
                     task.app.logger.warning(exc)
                     continue
-                except MaxRetriesExceedException as exc:
-                    task.app.logger.error(exc)
-                    break
                 except Exception:
                     task.remove()
                     task.app.logger.error(
